@@ -239,9 +239,9 @@
 /* Symbols we may use */
 /* #undef HAVE_SYS_ERRLIST */
 /* used by stacktrace functions */
-/* #undef HAVE_BACKTRACE */
-/* #undef HAVE_BACKTRACE_SYMBOLS */
-/* #undef HAVE_BACKTRACE_SYMBOLS_FD */
+#define HAVE_BACKTRACE 1
+#define HAVE_BACKTRACE_SYMBOLS 1
+#define HAVE_BACKTRACE_SYMBOLS_FD 1
 /* #undef HAVE_PRINTSTACK */
 #define HAVE_IPV6 1
 /* #undef ss_family */
@@ -528,16 +528,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 5
-#define MYSQL_VERSION_PATCH 11
+#define MYSQL_VERSION_PATCH 12
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.5.11"
+#define PACKAGE_STRING "MySQL Server 10.5.12"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.5.11"
-#define VERSION "10.5.11"
+#define PACKAGE_VERSION "10.5.12"
+#define VERSION "10.5.12"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
