@@ -1,4 +1,4 @@
-/* Copyright (c) 2020, MariaDB
+/* Copyright (c) 2020, 2021, MariaDB
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,6 +13,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1335  USA */
 
+#pragma once
 #ifdef __cplusplus
 #include <atomic>
 /**
@@ -40,9 +41,12 @@ public:
   Atomic_relaxed(Type val) : m(val) {}
   Atomic_relaxed() {}
 
-  operator Type() const { return m.load(std::memory_order_relaxed); }
-  Type operator=(const Type val)
-  { m.store(val, std::memory_order_relaxed); return val; }
+  Type load(std::memory_order o= std::memory_order_relaxed) const
+  { return m.load(o); }
+  void store(Type i, std::memory_order o= std::memory_order_relaxed)
+  { m.store(i, o); }
+  operator Type() const { return m.load(); }
+  Type operator=(const Type i) { store(i); return i; }
   Type operator=(const Atomic_relaxed<Type> &rhs) { return *this= Type{rhs}; }
   Type fetch_add(const Type i, std::memory_order o= std::memory_order_relaxed)
   { return m.fetch_add(i, o); }
@@ -50,6 +54,10 @@ public:
   { return m.fetch_sub(i, o); }
   Type fetch_xor(const Type i, std::memory_order o= std::memory_order_relaxed)
   { return m.fetch_xor(i, o); }
+  Type fetch_and(const Type i, std::memory_order o= std::memory_order_relaxed)
+  { return m.fetch_and(i, o); }
+  Type fetch_or(const Type i, std::memory_order o= std::memory_order_relaxed)
+  { return m.fetch_or(i, o); }
   bool compare_exchange_strong(Type& i1, const Type i2,
                                std::memory_order o1= std::memory_order_relaxed,
                                std::memory_order o2= std::memory_order_relaxed)
